<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Custom PHP JS Plugin Page class.
 *
 * @since 1.0.0
 *
 * @see CPJ_Plugin_Page
 */
if ( ! class_exists( 'CPJ_Plugin_Page' ) )
{
    class CPJ_Plugin_Page
    {
        public function __construct()
        {
            $this->adminOpName = __( 'JCI Plugin','post-page-manager' );
            add_action( 'admin_menu', array( $this, 'add_cpj_plugin_page' ) );
            add_action( 'admin_enqueue_scripts', array( $this, 'cpj_page_scripts' ) );
            add_action( 'wp_ajax_post_page_manager_modal_action', array( $this, 'post_page_manager_modal_action' ) );
            add_action( 'wp_ajax_save_post_page_manager_action', array( $this, 'save_post_page_manager_action' ) );
			
			
            add_action( 'category_edit_form_fields', array( $this, 'tax_edit_form' ) );
            add_action( 'category_add_form_fields', array( $this, 'tax_add_form' ) );
            add_action( 'create_category', array( $this, 'tax_save_form' ) );
            add_action( 'edited_category', array( $this, 'tax_save_form' ) );
            add_action( 'post_tag_edit_form_fields', array( $this, 'tax_edit_form' ) );
            add_action( 'post_tag_add_form_fields', array( $this, 'tax_add_form' ) );
            add_action( 'create_post_tag', array( $this, 'tax_save_form' ) );
            add_action( 'edited_post_tag', array( $this, 'tax_save_form' ) );
        }
        
        public function cpj_page_scripts()
        {
            $screen = get_current_screen();
	if (is_object($screen) && ( $screen->id == 'toplevel_page_' . CPJ_Tools::generateId( $this->adminOpName ) || $screen->id == 'edit-category' || $screen->id == 'edit-post_tag' ) )
            {
                wp_enqueue_script('jquery');
                wp_enqueue_media();
                
                CPJ_Tools::enqueue_style( 'bootstrap-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootstrap/bootstrap.min.css', false, '3.2.0' );
                CPJ_Tools::enqueue_script( 'bootstrap-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootstrap/bootstrap.min.js', array(), '3.2.0', true );
                CPJ_Tools::enqueue_script( 'jquery-notify', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/jquery-notify/src/jquery.notify.min.js', array(), '1.5', true );
                CPJ_Tools::enqueue_style( 'bootflat-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootflat/css/bootflat.min.css', false, '2.0.2' );
                wp_enqueue_style( 'font-awesome', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/font-awesome/css/font-awesome.min.css', true, '4.3.0' );
                CPJ_Tools::enqueue_script( 'ace-editor', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/ace-editor/ace.js', array(), '1.1.6', true );
                CPJ_Tools::enqueue_script( 'ace-auto-complete', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/ace-editor/ext-language_tools.js', array(), '1.1.6', true );
                
                // Enqueue Zomax Panels Custom Styles & Scripts.
                CPJ_Tools::enqueue_style( 'cpj-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/cpj/cpj.css', array(
                                                                                                        'bootstrap-css',
                                                                                                        'bootflat-css',
                                                                                                        'font-awesome',
                                                                                                        ), POST_PAGE_MANAGER_VERSION );
                CPJ_Tools::enqueue_script( 'cpj-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/cpj/cpj.js', array(
                                                                                                        'jquery',
                                                                                                        'bootstrap-js',
                                                                                                        'ace-editor',
                                                                                                        'ace-auto-complete',
                                                                                                        ), POST_PAGE_MANAGER_VERSION, true);
                
                wp_localize_script( 'cpj-js', "cpjTranslate", array(
                                                                    'adminOpId'             =>  CPJ_Tools::generateId( $this->adminOpName ),
                                                                    'enterFullscreen'       =>  __( 'Fullscreen On', 'post-page-manager' ),
                                                                    'exitFullscreen'        =>  __( 'Fullscreen Off', 'post-page-manager' ),
                                                                    'left'                  =>  ( is_rtl())? 'right' : 'left',
                                                                    'right'                 =>  ( is_rtl() )? 'left' : 'right',
                                                                    'press'                 =>  __( 'Press', 'post-page-manager' ),
                                                                    'forWord'               =>  __( 'for', 'post-page-manager' ),
                                                                    'autocompletion'        =>  __( 'Autocompletion', 'post-page-manager' ),
                                                                    'space'                 =>  __( 'Space', 'post-page-manager' ),
                                                                    'search'                =>  __( 'Search', 'post-page-manager' ),
                                                                    'and'                   =>  __( 'and', 'post-page-manager' ),
                                                                    'replace'               =>  __( 'Replace', 'post-page-manager' ),
                                                                    )
                                                                    );
            }
        }
        /**
         * Add cpj options page
         */
        public function add_cpj_plugin_page()
        {
            // This page will be under "Appearance"
            add_menu_page($this->adminOpName, 
                          $this->adminOpName,
                          'edit_posts',
                          CPJ_Tools::generateId( $this->adminOpName ),
                          array( $this, '_create_cpj_options_html' ),
                          POST_PAGE_MANAGER_PLUGIN_URL . 'assets/head-icon.ico',
                          61 );
        }
    
        public function _create_cpj_options_html()
        {
            ?>
            <div class="cpj-container">
            	<div class="row">
            		<div class="col-md-12">
                        	<div class="panel cpj-default-header-panel">
                				<h1><?php _e( "JCI Plugin", "post-page-manager" ); ?> <small style="color: black;">v <?php echo POST_PAGE_MANAGER_VERSION; ?></small></h1>
                                <img class="img-responsive pull-right" src="<?php echo POST_PAGE_MANAGER_PLUGIN_URL . 'assets/BlackJack_Logo.png'; ?>" style="max-width:205px;margin-top: -40px;" />
                			</div>
            		</div>
            	</div>
            	<div class="row">
            		<div class="col-md-12">
            			<div class="btn-group-vertical cpj-btn-group-vertical" id="tabs-main-btn">
                            <?php
                            $post_types = CPJ_Tools::post_type_array();
                            $i = 0;
                            foreach( $post_types as $id => $name ){
                                if($i == 0){
                                ?>
                                <a class="btn btn-default-in btn-right active" href="<?php echo admin_url( "admin.php?page=" . CPJ_Tools::generateId( $this->adminOpName ) ); ?>&amp;apptab=cpj_<?php echo $id; ?>"><span class="dashicons dashicons-admin-<?php echo $id; ?>"></span> <?php echo $name; ?></a>
                                <a class="hidden" href="#cpj_<?php echo $id; ?>"><?php _e( 'Posts','post-page-manager' ); ?></a>
                                <?php
                                } else {
                                ?>
                                <a class="hidden" href="#cpj_<?php echo $id; ?>"><?php _e( 'Pages','post-page-manager' ); ?></a>
                                <a class="btn btn-default-in btn-right" href="<?php echo admin_url( "admin.php?page=" . CPJ_Tools::generateId( $this->adminOpName ) ); ?>&amp;apptab=cpj_<?php echo $id; ?>"><span class="dashicons dashicons-admin-<?php echo $id; ?>"></span> <?php echo $name; ?></a>
                                <?php
                                }
                            $i++;
                            }
                            ?>
            			</div>
            			<div class="tab-content tabs-main-content" id="tabs-main-content">
                            <?php
                            $i = 0;
                            foreach( $post_types as $id => $name ){
                            ?>
                            <div class="tab-pane panel panel-body<?php echo(!$i)?' active':''; ?>" id="cpj_<?php echo $id; ?>">
                                <?php $this->get_posts_table($id); ?>
                            </div>
                            <?php
                            $i++;
                            }
                            ?>
            			</div>
            		</div>
            		<!-- .col-md-9 -->
            	</div>
            	<!-- .row -->
                <div class="ajax-waiting text-center v-center"></div>
                <?php $this->post_codes_modal(); ?>
            </div>
            <!-- .cpj-container -->
            <div class="cpj-notify-container col-md-3">
                <div id="success" class="alert alert-success cpj-notify">
            		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                    <h4>#{title}</h4>
            		#{msg}
            	</div>
                <div id="danger" class="alert alert-danger cpj-notify">
            		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                    <h4>#{title}</h4>
            		#{msg}
            	</div>
                <div id="warning" class="alert alert-warning cpj-notify">
            		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                    <h4>#{title}</h4>
            		#{msg}
            	</div>
                <div id="info" class="alert alert-info cpj-notify">
            		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                    <h4>#{title}</h4>
            		#{msg}
            	</div>
            </div>
            <!-- #cpj-notify-container -->
            <?php
        }
        public function get_posts_table( $post_type ){
            if( ! post_type_exists( $post_type ) )
                return sprintf( __( 'Post Type "%s" not exist!', "post-page-manager" ), $post_type );
            ?>
            <div class="row">
            	<div class="col-md-12">
            		<h4>
            			<?php echo __( "Posts List of Post Type:", "post-page-manager" ) . ' "' . $post_type . '"'; ?>
            		</h4>
            	</div>
            </div>
            <br /><br />
            <div class="row">
            	<div class="col-md-12">
            		<div class="table-responsive">
            			<table class="table table-striped table-hover">
            				<thead>
            					<tr>
            						<th>
            							#
            						</th>
            						<th>
                                            <?php _e( "Post Name", "post-page-manager" ); ?>
            						</th>
            						<th>
            							<?php _e( "Post ID", "post-page-manager" ); ?>
            						</th>
            						<th class="text-right">
            							<span style="margin-right:10px;">
            							<?php _e( "JCI Plugin", "post-page-manager" ); ?>
                                        </span>
            						</th>
            					</tr>
            				</thead>
            				<tbody>
            					<?php
                                global $current_user;
                                get_currentuserinfo();                      
                                
                                $args_all = array(
                                        'author'            =>  $current_user->ID,
                                        'orderby'           =>  'post_date',
                                        'post_type'         =>  $post_type,
                                        'order'             =>  'ASC',
                                        'posts_per_page'    => -1
                                        );                    
                                $current_user_posts_all = get_posts( $args_all );
                                $args = array(
                                        'author'            =>  $current_user->ID,
                                        'orderby'           =>  'post_date',
                                        'post_type'         =>  $post_type,
                                        'order'             =>  'ASC',
                                        'posts_per_page'    => -1
                                        );
                                
                                // get his posts 'ASC'
                                $current_user_posts = get_posts( $args );
                                $i = 0;
                                
                                foreach( $current_user_posts as $post ) {
                                    $i++;
                                    $post_title = ($post->post_title !='')? $post->post_title: __( "No Title", "post-page-manager" );
                                    $php_class = ( get_post_meta ( $post->ID, 'post_page_manager_code_php', true ) !='' )?' btn-info' :'';
                                    $js_class = ( get_post_meta ( $post->ID, 'post_page_manager_code_js', true ) !='' )?' btn-success' :'';
                                    echo '
            						<tr>
            							<td class="v-center">
            								' . $i . '
            							</td>
            							<td class="text-primary v-center">
            								<strong>' . $post_title . '</strong>
            							</td>
            							<td class="text-primary v-center">
            								<strong>' . $post->ID . '</strong>
            							</td>
            							<td class="text-right">
            								<button class="btn' . $php_class . ' btn-sm edit-code" data-toggle="modal" data-target="#post-page-manager-form-modal" data-postname="' . $post_title . '" data-type="php" data-key="'. $post->ID .'" style="margin-right:15px;">
            									<i class="dashicons dashicons-editor-code">
            									</i>
            									' . __( "PHP", "post-page-manager" ) . '
            								</button>
            								<button class="btn' . $js_class . ' btn-sm edit-code" data-toggle="modal" data-target="#post-page-manager-form-modal" data-postname="' . $post_title . '" data-type="js" data-key="'. $post->ID .'">
            									<i class="dashicons dashicons-editor-code">
            									</i>
            									' . __( "JS", "post-page-manager" ) . '
            								</button>
            							</td>
            						</tr>
            						'; } ?>
            				</tbody>
            			</table>
            		</div>
            	</div>
            </div>
            <?php
        }
        public function post_codes_modal()
        {
            ?>
            <!-- Modal -->
            <div class="modal fade" id="post-page-manager-form-modal" tabindex="-1" role="dialog" aria-labelledby="post-page-manager-form-modal-title" aria-hidden="true">
            	<div class="modal-dialog modal-lg">
            		<div class="modal-content">
            			<div class="modal-header">
            				<button type="button" class="close" data-dismiss="modal" aria-hidden="true">
            					&times;
            				</button>
            				<h4 class="modal-title post-page-manager-form-modal-title" id="post-page-manager-form-modal-title">
            					<span></span><span class="postTitle"></span>
            				</h4>
						</div>
            			<div class="modal-body">
            				<form method="post" id="post-page-manager-form">
            					<br />
            					<div id="formContent"></div>
            					<div class="modal-footer">
            						<span class="pull-left">
            							<?php //printf( __( "Starred fields %s are Required", "post-page-manager" ), '(<span class="text-danger"> * </span>)' ); ?>
            						</span>
            						<button type="button" class="btn btn-default" data-dismiss="modal">
            							<?php _e( "Close", "post-page-manager" ); ?>
            						</button>
            						<button type="submit" class="btn btn-warning post-page-manager-form-form-submit">
            							<?php _e( "Save Options", "post-page-manager" ); ?>
            						</button>
            					</div>
            				</form>
            			</div>
            		</div>
            	</div>
            </div>
            <?php
        }
        public function post_page_manager_modal_action()
        {
            $code_type  = $_POST['code_type'];
            $post_id    = $_POST['post_id'];
            $code       = wp_unslash( get_post_meta ( $post_id, 'post_page_manager_code_' . $code_type, true ) );
            $title      = wp_unslash( get_post_meta ( $post_id, 'post_page_manager_code_' . $code_type .'_title', true ) );
            $position   = wp_unslash( get_post_meta ( $post_id, 'post_page_manager_code_' . $code_type .'_position', true ) );
            $position   = ($position)?$position:'head';
            ?>
            <div class="row">
				<div class="col-sm-6">
					<label for="post-page-manager-form-id" title="<?php _e( "Title", "post-page-manager" ); ?>">
						<?php _e( "Title", "post-page-manager" ); ?>
					</label>
                    <span class="text-danger"> * </span>
					<input type="text" class="form-control" id="post-page-manager-form-id" name="title" placeholder="<?php _e( "Title / Name", "post-page-manager" ); ?>" value="<?php echo $title; ?>" />
					<span class="help-block">
						<?php _e( "Title to describe the purpose of the code used.", "post-page-manager" ); ?>
					</span>
				</div>
                <?php if($code_type == 'js'){ ?>
				<div class="col-sm-6">
					<label style="margin-bottom:10px" for="post-page-manager-form-description" title="<?php _e( "Code", "post-page-manager" ); ?>">
						<?php _e( "JS Code Position", "post-page-manager" ); ?>
					</label><br />
                    <label class="radio-inline"><input type="radio" name="position" value="head"<?php echo ($position=='head')?' checked':''; ?>/>Inside <code>&lt;HEAD&gt;</code></label>
                    <label class="radio-inline"><input type="radio" name="position" value="body"<?php echo ($position=='body')?' checked':''; ?>/>Inside <code>&lt;BODY&gt;</code></label>
				</div>
                <?php } ?>
                <div class="col-sm-12" style="margin-top: 15px;">
    				<label style="margin-bottom:10px" for="post-page-manager-form-description" title="<?php _e( "Menu Description.", "post-page-manager" ); ?>">
    					<?php echo strtoupper($code_type) . " Code"; ?>
    				</label><br />
                    <textarea name="code" class="form-control ace-textarea" data-theme="cobalt" data-mode="<?php echo ($code_type=='php')?'php':'javascript'; ?>"><?php echo esc_textarea($code); ?></textarea>
                </div>
                <input type="hidden" name="post_id" value="<?php echo $post_id; ?>" />
                <input type="hidden" name="code_type" value="<?php echo $code_type; ?>" />
				<input type="hidden" name="action" value="save_post_page_manager_action" />
				<?php wp_nonce_field( 'cpj_nonce', 'customPhpJsNonce'); ?>
			</div>
            <?php
            die();
        }
        public function save_post_page_manager_action()
        {
            //if ( !current_user_can( 'edit_page', $_POST['post_id'] ) && !current_user_can( 'edit_post', $_POST['post_id'] ) ){
            if ( ! isset($_POST['customPhpJsNonce'] ) || ! wp_verify_nonce( $_POST['customPhpJsNonce'], 'cpj_nonce' ) ){
                CPJ_Tools::notify('danger', __( "Security Error", "post-page-manager" ), __( "Sorry, your nonce did not verify.", "post-page-manager" ), "15000" );
                return 'Somthing Error';
            }
            
            $_POST['code'] = wp_slash( $_POST['code'] );
            $_POST['title'] = wp_slash( $_POST['title'] );
            $_POST['position'] = wp_slash( $_POST['position'] );
                
            
            delete_post_meta( $_POST['post_id'], 'post_page_manager_code_' . $_POST['code_type'] );
            delete_post_meta( $_POST['post_id'], 'post_page_manager_code_' . $_POST['code_type'] . '_title' );
            delete_post_meta( $_POST['post_id'], 'post_page_manager_code_' . $_POST['code_type'] . '_position' );
            if( add_post_meta( $_POST['post_id'], 'post_page_manager_code_' . $_POST['code_type'], $_POST['code'] ) &&
                add_post_meta( $_POST['post_id'], 'post_page_manager_code_' . $_POST['code_type'] . '_title', $_POST['title'] )&&
                add_post_meta( $_POST['post_id'], 'post_page_manager_code_' . $_POST['code_type'] . '_position', $_POST['position'] )  )
            {
                CPJ_Tools::notify('success', __( "Code Saved Successfully!", "post-page-manager" ), __( "Your new code value save successfully.", "post-page-manager" ), "15000" );
            }
            die();
                
            
        }
		
		public function tax_add_form($tax){
			?>
			<style>
			html{background:#f1f1f1;}
			ul#adminmenu a.wp-has-current-submenu:after,ul#adminmenu>li.current>a.current:after{border:12px solid transparent;border-right-color:#f1f1f1;margin-top:-12px}@media screen and (min-width:782px){ul#adminmenu a.wp-has-current-submenu:after,ul#adminmenu>li.current>a.current:after{border:17px solid transparent;border-right-color:#f1f1f1;border-top-color:#f1f1f1;border-bottom-color:#f1f1f1;margin-top:-17px;right:-15px;-webkit-border-radius:50%;-moz-border-radius:50%;border-radius:50%}}
			.form-table input.tog, .form-table input[type=radio]{margin-top:0;}
			</style>
			<tr class="form-field">
				<th scope="row"><label for="cpj[php]"><?php _e( 'Custom PHP Code' ); ?></label></th>
				<td><textarea name="cpj[php]" class="form-control ace-textarea" data-theme="cobalt" data-mode="php"></textarea></td>
			</tr>
			<tr class="form-field">
				<th scope="row"><label for="cpj[js]"><?php _e( 'Custom Javascript Code' ); ?></label></th>
				<td><textarea name="cpj[js]" class="form-control ace-textarea" data-theme="cobalt" data-mode="javascript"></textarea></td>
			</tr>
			<tr class="form-field">
				<th scope="row"><label for="cpj[position]"><?php _e( 'Javascript Code Position' ); ?></label></th>
				<td>
				<label class="radio-inline"><input type="radio" name="cpj[position]" value="head" checked/>Inside <code>&lt;HEAD&gt;</code></label>
				<label class="radio-inline"><input type="radio" name="cpj[position]" value="body"/>Inside <code>&lt;BODY&gt;</code></label>
				</td>
			</tr>
			<?php
		}
		public function tax_edit_form($tax){
			$tax_id = $tax->term_id;
			$tax_meta = get_option("cpj_tax_$tax_id");
			?>
			<style>
			html{background:#f1f1f1;}
			ul#adminmenu a.wp-has-current-submenu:after,ul#adminmenu>li.current>a.current:after{border:12px solid transparent;border-right-color:#f1f1f1;margin-top:-12px}@media screen and (min-width:782px){ul#adminmenu a.wp-has-current-submenu:after,ul#adminmenu>li.current>a.current:after{border:17px solid transparent;border-right-color:#f1f1f1;border-top-color:#f1f1f1;border-bottom-color:#f1f1f1;margin-top:-17px;right:-15px;-webkit-border-radius:50%;-moz-border-radius:50%;border-radius:50%}}
			.form-table input.tog, .form-table input[type=radio]{margin-top:0;}
			</style>
			<tr class="form-field">
				<th scope="row"><label for="cpj[php]"><?php _e( 'Custom PHP Code' ); ?></label></th>
				<td><textarea name="cpj[php]" class="form-control ace-textarea" data-theme="cobalt" data-mode="php"><?php echo $tax_meta['php']? esc_textarea(wp_unslash($tax_meta['php'])) : ''; ?></textarea></td>
			</tr>
			<tr class="form-field">
				<th scope="row"><label for="cpj[js]"><?php _e( 'Custom Javascript Code' ); ?></label></th>
				<td><textarea name="cpj[js]" class="form-control ace-textarea" data-theme="cobalt" data-mode="javascript"><?php echo $tax_meta['js']? esc_textarea(wp_unslash($tax_meta['js'])) : ''; ?></textarea></td>
			</tr>
			<tr class="form-field">
				<th scope="row"><label for="cpj[position]"><?php _e( 'Javascript Code Position' ); ?></label></th>
				<td>
				<label class="radio-inline"><input type="radio" name="cpj[position]" value="head"<?php echo ($tax_meta['position']=='head')?' checked':''; ?>/>Inside <code>&lt;HEAD&gt;</code></label>
				<label class="radio-inline"><input type="radio" name="cpj[position]" value="body"<?php echo ($tax_meta['position']=='body')?' checked':''; ?>/>Inside <code>&lt;BODY&gt;</code></label>
				</td>
			</tr>	
			<?php
		}
		public function tax_save_form($tax_id){
			if( isset( $_POST['cpj'] ) )
			{
				$tax_meta = get_option("cpj_tax_$tax_id");
				foreach ( $_POST['cpj'] as $key => $value )
				{
					$tax_meta[$key] = $value;
				}
				update_option( "cpj_tax_$tax_id", $tax_meta );
			}
		}
    }
}


function CPJ_Plugin_Page_init()
{
  if ( current_user_can( 'edit_posts' ) ) {
    new CPJ_Plugin_Page();
  }
}

add_action( 'after_setup_theme', 'CPJ_Plugin_Page_init' );

if ( ! function_exists( 'cpj_php_code' ) )
{
    function cpj_php_code()
    {
        if ( ! is_singular() )
            return;
                
        global $post;
        $php_code = get_post_meta( $post->ID, 'post_page_manager_code_php', true );
        $php_code = wp_unslash($php_code);
		$tag_ids = wp_get_post_tags( $post->ID, array( 'fields' => 'ids' ) );
		$cats_ids = wp_get_post_categories( $post->ID, array( 'fields' => 'ids' ) );
		$terms_ids = array_merge( $tag_ids, $cats_ids );
		foreach( $terms_ids as $id )
		{
			$meta = get_option("cpj_tax_$id");
			$php_code .= wp_unslash($meta['php']) ;
		}
        $php_code = str_replace('<?php', '', $php_code);
        $php_code = str_replace('?>', '', $php_code);
    	
    	eval($php_code);
    }
}






function cjs_post_page_manager_head()
{
    if ( is_singular() )
	{
		global $post;
		$js_code       = get_post_meta ( $post->ID, 'post_page_manager_code_js', true );
		$js_code       = wp_unslash($js_code);
		$js_position   = get_post_meta ( $post->ID, 'post_page_manager_code_js_position', true );
		
		if( $js_position == 'head' ){
			echo $js_code;   
		}
	}elseif( is_tag() || is_category() || is_tax() )
	{
		$queried_object = get_queried_object();
		$id = ( is_object( $queried_object ) )? $queried_object->term_id: null;
		$meta = get_option("cpj_tax_$id");
		if( $meta['position'] == 'head' ){
			echo wp_unslash($meta['js']);   
		}
	}else{
		return;
	}
}
add_action( 'wp_head', 'cjs_post_page_manager_head' );
function cjs_post_page_manager_body()
{
    if ( is_singular() )
	{
		global $post;
		$js_code       = get_post_meta ( $post->ID, 'post_page_manager_code_js', true );
		$js_code       = wp_unslash($js_code);
		$js_position   = get_post_meta ( $post->ID, 'post_page_manager_code_js_position', true );
		
		if( $js_position == 'body' ){
			echo $js_code;   
		}
	}elseif( is_tag() || is_category() || is_tax() )
	{
		$queried_object = get_queried_object();
		$id = ( is_object( $queried_object ) )? $queried_object->term_id: null;
		$meta = get_option("cpj_tax_$id");
		if( $meta['position'] != 'head' ){
			echo wp_unslash($meta['js']);   
		}
	}else{
		return;
	}
}
add_action( 'wp_footer', 'cjs_post_page_manager_body' );
function cjs_post_page_manager_PHP()
{
    if ( is_singular() )
	{
		global $post;
		$php_code = get_post_meta ( $post->ID, 'post_page_manager_code_php', true );
		$php_code = wp_unslash($php_code);
		$php_code = str_replace('<?php', '', $php_code);
		$php_code = str_replace('?>', '', $php_code);
		
		eval($php_code);
    
	}elseif( is_tag() || is_category() || is_tax() )
	{
		$queried_object = get_queried_object();
		$id = ( is_object( $queried_object ) )? $queried_object->term_id: null;
		$meta = get_option("cpj_tax_$id");
		$php_code = wp_unslash($meta['php']);
		$php_code = str_replace('<?php', '', $php_code);
		$php_code = str_replace('?>', '', $php_code);
		
		eval($php_code);
	}else{
		return;
	}
}
add_action( 'wp', 'cjs_post_page_manager_PHP', 999999999 );

//usage before wp_head()
//if( function_exists( 'cpj_php_code' ) ){cpj_php_code();}

function sdfsdfd_img_icon_max() {
  ?>
  <style>#adminmenu .wp-menu-image img{padding:5px 0 0;max-height:24px;max-width:24px;height: auto;width: auto}</style>
  <?php
}
add_action( 'admin_head', 'sdfsdfd_img_icon_max' );