<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
if ( ! class_exists( 'ZMX_Form' ) )
{
    class ZMX_Form
    {   
        /**
         * Hook into the appropriate actions when the class is constructed.
         * Redirect Zomax form actions to 'cpj_ajax_update_options' method.
         */ 
        public function __construct()
        {
            add_action( 'wp_ajax_cpj_ajax_update_options', array( $this, 'cpj_ajax_update_options' ) );
        }
        
        /**
         * Update and save form option into cpj option array as array value associated
         * with key same as form_location field value sent with $_POST array.
         * 
         * @since 1.0.0
         */ 
        public function cpj_ajax_update_options()
        {
            $nonceField = 'cpjAjaxGeneralNonce' . CPJ_Tools::generateId( $_POST['form_location'] );
            if ( ! isset( $_POST[ $nonceField ] ) || ! wp_verify_nonce( $_POST[ $nonceField ], 'cpj-next-nonce' ) )
            {
                CPJ_Tools::notify( "danger", __( "Security Error", "post-page-manager" ),  __( "Sorry, your nonce did not verify.", "post-page-manager" ), "15000" );
            } elseif ( CPJ_Tools::update_option( "general", $_POST['form_location'], $_POST ) )
            {
                CPJ_Tools::notify( "success",  CPJ_Tools::id2title( $_POST['form_location'] ).__( " Updated!", "post-page-manager" ),  CPJ_Tools::id2title( $_POST['form_location'] ) . __( " options updated successfully.", "post-page-manager" ), "15000" );
            } else
            {
                CPJ_Tools::notify( "warning", __( "No Changes!", "post-page-manager" ),  __( "An Error happens or there's no changes made to options.", "post-page-manager" ), "15000" );
            }
            die();
        }
        
        /**
         * Output form header with hidden inputs to provide necessary values.
         * 
         * @since 1.0.0
         * 
         * @param string $location  Form field value saved as key value array under this
         *                          key ($location) inside cpj options array.
         */ 
        public static function start( $location )
        {
            ?>
            <form method="post" class="cpj-ajax-general-update">
                <input type="hidden" name="action" value="cpj_ajax_update_options" />
                <input type="hidden" name="form_location" value="<?php echo $location; ?>"/>
            <?php 
                $nonceField = 'cpjAjaxGeneralNonce' . CPJ_Tools::generateId( $location );
                wp_nonce_field( 'cpj-next-nonce', $nonceField );
        }
        
        /**
         * Output form footer (form closure) at the end of option panel.
         * 
         * @since 1.0.0
         * 
         * @param string    $text   Text on form submit button. Default null.
         * @param bool      $reset  Whether to enable reset button or not. Default true.
         */ 
        public static function end( $text = null, $reset = true )
        {
            if( is_null( $text ) ) {
                $text = __( "Update Options", "post-page-manager" );
            }
            ?>
                <div class="fix-doc-height"></div>
            	<div class="cpj-submit-footer panel-footer">
                    <div class="btn-group pull-left">
                        <a class="btn btn-sm btn-default scroll-windows-down"><span class="glyphicon glyphicon-chevron-down"></span></a>
                        <a class="btn btn-sm btn-default scroll-windows-up"><span class="glyphicon glyphicon-chevron-up"></span></a>
                    </div>
                    <?php if( $reset ) { ?>
            		<button type="reset" class="btn btn-default" >
            			<?php _e("Reset", "cpj"); ?>
            		</button>
                    <?php } ?>
            		<button type="submit" class="btn btn-primary" >
            			<?php echo $text; ?>
            		</button>
                </div>
            </form>
            <?php
        }
        
        /**
         * Print Field HTML Code
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field( $args = array() )
        {
            $args = CPJ_Tools::array_remove_empty_deep( $args );
                      
            if ( ! array_key_exists( 'id', $args ) ) {
                $args['id'] = false;
            }
            if ( array_key_exists( 'attr', $args ) ) {
                if ( array_key_exists( 'type', $args['attr'] ) ) {
                    $args['attrType'] = $args['attr']['type'];
                    unset( $args['attr']['type'] );
                }else {
                    $args['attrType'] = false;
                }
                if ( array_key_exists( 'name', $args['attr'] ) ) {
                    $args['attrName'] = $args['attr']['name'];
                    unset( $args['attr']['name'] );
                }else{
                    $args['attrName'] = false;
                }
                if ( array_key_exists( 'class', $args['attr'] ) ) {
                    $args['attrClass'] = ' '. $args['attr']['class'];
                    unset( $args['attr']['class'] );
                }else{
                    $args['attrClass'] = false;
                }
                if ( array_key_exists( 'multiple', $args['attr'] ) ) {
                    $args['attrMulti'] = $args['attr']['multiple'];
                    unset( $args['attr']['multiple'] );
                }
                if ( array_key_exists( 'placeholder', $args['attr'] ) ) {
                    $args['attrPlaceholder'] = $args['attr']['placeholder'];
                    unset( $args['attr']['placeholder'] );
                }else{
                    $args['attrPlaceholder'] = false;
                }
                $attr = '';
                foreach( $args['attr'] as $key => $value ){
                    $attr .= $key . '="' . $value . '" ';
                }
                $args['attr'] = $attr;
            }else{
                $args['attr'] = false;
            }     
            if ( array_key_exists( 'class', $args ) && array_key_exists( 'attrClass', $args ) ) {
                $args['class'] = ' '. $args['class'] . $args['attrClass'];
            }elseif( array_key_exists( 'class', $args ) ){
                $args['class'] = ' '. $args['class'];
            }elseif( array_key_exists( 'attrClass', $args ) ){
                $args['class'] = ' '.$args['attrClass'];
            }else{
                $args['class'] = false;
            }      
            if ( array_key_exists( 'multiple', $args ) ) {
                if( $args['multiple'] === true || $args['multiple'] == 'true' ){
                    $args['multiple'] = true;
                }else {
                    $args['multiple'] = false;
                } 
            }else{
                $args['multiple'] = false;
            }
            if ( ! array_key_exists( 'value', $args ) ) {
                $args['value'] = false;
            }
            if ( ! array_key_exists( 'title', $args ) ) {
                $args['title'] = false;
            }
            if ( ! array_key_exists( 'subtitle', $args ) ) {
                $args['subtitle'] = false;
            }
            if ( ! array_key_exists( 'note', $args ) ) {
                $args['note'] = false;
            }
            
            $fields_array = array(
            'text',
            'textarea',
            'number',
            'toggle',
            'code',
            'select',
            'checkbox',
            'radio',
            'color',
            'media',
            'typography',
            );
            
            if ( array_key_exists( 'type', $args ) && $args['id'] && in_array( $args['type'], $fields_array ) ) {
                if ( array_key_exists( 'columns', $args ) ) {      
                    switch ( $args['columns'] ) {
                        case 'none':
                            self::field_template_none( $args );
                            break;
                        case 'one':
                            self::field_template_one( $args );
                            break;
                        case 'two':
                            self::field_template_twoR( $args );
                            break;
                        case 'two-right':
                            self::field_template_twoR( $args );
                            break;
                        case 'two-left':
                            self::field_template_twoL( $args );
                            break;
                        case 'three':
                            self::field_template_three( $args );
                            break;
                        default:
                            self::field_template_twoR( $args );
                    }
                }else
                {
                    self::field_template_twoR( $args );
                }
            }else 
            {
                _e( "Can't recognize field type and/or id.", "post-page-manager" );
            }
        }
        
        /**
         * Print Field HTML Code Only
         * 
         * Output HTML code of field without title, subtitle or note.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_template_none( $args = array() )
        {
            call_user_func( array( __CLASS__, 'field_' . $args['type'] ), $args );
        }
        
        /**
         * Print field HTML code arranged in one column.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_template_one( $args = array() )
        {
            ?>
            <div class="row">
                <div class="col-md-12">
                    <label class="font-14"><?php if( $args['title'] ) { echo( $args['title'] ); }?></label>
                    <p class="text-muted"><?php if( $args['subtitle'] ) { echo( $args['subtitle'] ); }?></p>
                    <?php call_user_func( array( __CLASS__, 'field_'.$args['type'] ), $args ); ?>
                    <p><?php if( $args['note'] ){ echo( $args['note'] ); }?></p>
                </div>
            </div>
            <hr />
            <?php
        }
        
        /**
         * Print field HTML code arranged in two columns.
         * Form field at right column.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_template_twoR( $args = array() )
        {
            ?>
            <div class="row">
                <div class="col-md-4">
                    <label class="font-14"><?php if( $args['title'] ) { echo( $args['title'] ); } ?></label>
                    <p class="text-muted"><?php if( $args['subtitle'] ) { echo( $args['subtitle'] ); } ?></p>
                </div>
                <div class="col-md-8">
                    <?php call_user_func( array( __CLASS__, 'field_' . $args['type'] ), $args ); ?>
                    <p><?php if( $args['note'] ){ echo( $args['note'] ); }?></p>
                </div>
            </div>
            <hr />
            <?php
        }
        
        /**
         * Print field HTML code arranged in two columns.
         * Form field at left column.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_template_twoL( $args = array() )
        {
            ?>
            <div class="row">
                <div class="col-md-12">
                    <label class="font-14"><?php if( $args['title'] ){ echo( $args['title'] ); } ?></label>
                    <span class="text-muted"><?php if( $args['subtitle'] ) { echo( $args['subtitle'] ); } ?></span>
                </div>
                <div class="col-md-8">
                    <?php call_user_func( array( __CLASS__, 'field_' . $args['type'] ), $args ); ?>
                </div>
                <div class="col-md-4">
                    <p><?php if( $args['note'] ) { echo( $args['note'] ); } ?></p>
                </div>
            </div>
            <hr />
            <?php
        }
        
        /**
         * Print field HTML code arranged in three columns.
         * Form field in the middle.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_template_three( $args = array() )
        {
            ?>
            <div class="row">
                <div class="col-md-3">
                    <label class="font-14"><?php if( $args['title'] ) { echo( $args['title'] ); } ?></label>
                    <p class="text-muted"><?php if( $args['subtitle'] ) { echo( $args['subtitle'] ); } ?></p>
                </div>
                <div class="col-md-6">
                    <?php call_user_func( array( __CLASS__, 'field_' . $args['type'] ), $args ); ?>
                </div>
                <div class="col-md-3">
                    <p><?php if( $args['note'] ) { echo( $args['note'] ); } ?></p>
                </div>
            </div>
            <hr />
            <?php
        }
        
        /**
         * Print Text Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_text( $args = array()  )
        {
            if( array_key_exists( 'placeholder', $args ) ) {
                $placeholder = $args['placeholder'];
            }elseif( array_key_exists( 'attrPlaceholder', $args ) ){
                $placeholder = $args['attrPlaceholder'];
            }else{
                $placeholder = false;
            }
            if( ! $args['value'] ) {
                $args['value'] = "";
            }
            ?>
            <input name="<?php echo $args['id']; ?>" type="<?php if( $args['type'] ) { echo( $args['type'] ); } else { echo( 'text' ); } ?>" value="<?php echo $args['value']; ?>" class="form-control<?php if( $args['class'] ) { echo( $args['class'] ); } ?>"  <?php if( $placeholder ) { echo( 'placeholder="' . $placeholder . '" ' ); } ?><?php if( $args['attr'] ) { echo( $args['attr'] ); } ?>/>
            <?php
        }
        
        /**
         * Print Textarea Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_textarea( $args = array() )
        {
            if( array_key_exists( 'placeholder', $args ) ) {
                $placeholder = $args['placeholder'];
            }elseif( array_key_exists( 'attrPlaceholder', $args ) ) {
                $placeholder = $args['attrPlaceholder'];
            }else{
                $placeholder = false;
            }
            if( ! $args['value'] ){
                $args['value']= "";
            }
            ?>
            <textarea name="<?php echo $args['id'];?>" class="form-control<?php if( $args['class'] ){ echo( $args['class'] ); } ?>" <?php if( $placeholder ) { echo( 'placeholder="' . $placeholder . '" ' ); } ?><?php if( $args['attr'] ) { echo( $args['attr'] ); } ?>><?php echo $args['value']; ?></textarea><br />
            <?php
        }
        
        /**
         * Print Number Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_number( $args = array() )
        {
            if( array_key_exists( 'placeholder', $args ) ){
                $placeholder = $args['placeholder'];
            }elseif( array_key_exists( 'attrPlaceholder', $args ) ){
                $placeholder = $args['attrPlaceholder'];
            }else{
                $placeholder = false;
            }
            if( ! $args['value'] )
            {
                $args['value']= 0;
            }
            ?>
            <input name="<?php echo $args['id'];?>" type="number" value="<?php echo $args['value']; ?>" class="form-control<?php if( $args['class'] ) { echo( $args['class'] ); } ?>" <?php if( $placeholder ){ echo( 'placeholder="' . $placeholder . '" ' ); } ?><?php if( $args['attr'] ) { echo( $args['attr'] ); } ?>/>

            <?php
        }
        
        /**
         * Print Toggle Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_toggle( $args = array() )
        {
            if( $args['value'] == "on" ) {
                $args['checked']= " checked=\"checked\"";
            }else{
                $args['checked']= "";
                $args['value']= "off";
            }
            ?>
            <div>
                <label class="toggle zmx-toggle-field">
            	  <input name="<?php echo $args['id'];?>_checkbox_toggle" type="checkbox" class="form-control<?php if( $args['class'] ) { echo( $args['class'] ); } ?>" <?php if( $args['attr'] ) { echo( $args['attr'] ); } ?><?php echo $args['checked'];?>/>
            	  <span class="handle"></span>
            	</label>
                <input name="<?php echo $args['id'];?>" type="hidden" class="form-control" value="<?php echo( $args['value'] ); ?>"/>
            </div>
            <?php
        }
        
        /**
         * Print Code Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_code( $args = array() )
        {
            if ( ! array_key_exists( 'mode', $args ) ) {
                    $args['mode'] = 'php';
            }      
            if ( ! array_key_exists( 'theme', $args ) ) {
                    $args['theme'] = 'cobalt';
            }
            if( ! $args['value'] ) {
                $args['value']= "";
            }
            ?>
            <textarea name="<?php echo $args['id'];?>" class="form-control ace-textarea<?php if( $args['class'] ) { echo( $args['class'] ); } ?>" data-theme="<?php echo( $args['theme'] ); ?>" data-mode="<?php echo( $args['mode'] ); ?>" <?php if( $args['attr'] ) { echo( $args['attr'] ); } ?>><?php echo $args['value'];?></textarea>
            <?php
        }
        
        /**
         * Print Select Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_select( $args = array() )
        {
            if( array_key_exists( 'attrMulti', $args ) ) {
                $args['multiple'] = true;
            }
            if( array_key_exists( 'placeholder', $args ) ) {
                $placeholder = $args['placeholder'];
            }elseif( array_key_exists( 'attrPlaceholder', $args ) ) {
                $placeholder = $args['attrPlaceholder'];
            }else {
                $placeholder = false;
            }
            if( ! array_key_exists( 'options', $args ) ) {
                $args['options'] = array();
            }
            if( array_key_exists( 'open', $args ) && $args['open'] == 'up' ) {
                $args['open'] = ' chosen-at-end';
            }else {
                $args['open'] = false;
            }
            if( ! $args['value'] || ! is_array($args['value'] ) ) {
                $args['value'] = array();
            }
            ?>
            <select name="<?php echo $args['id'];?>[]" <?php if( $placeholder ) { echo( 'data-placeholder="' . $placeholder.'"' ); } ?> class="chosen<?php if( $args['class'] ) { echo( $args['class'] ); } ?><?php if( is_rtl() ) { echo( ' chosen-rtl' ); } ?><?php if( $args['open'] ) { echo( $args['open'] ); } ?>" <?php if( $args['multiple'] ) { echo('multiple '); } ?><?php if( $args['attr'] ) { echo( $args['attr'] ); } ?>>
                <?php if( $placeholder && ! $args['multiple'] ){echo('<option></option>');} ?>
                <?php foreach ( $args['options'] as $value => $title ) { ?>
                    <?php if( is_array( $title ) ) {?>
                    <optgroup label="<?php echo( $value ); ?>">
                        <?php foreach ( $title as $opValue => $opTitle ) { ?>
                        <option value="<?php echo( $opValue ); ?>"<?php if( in_array( $opValue, $args['value'] ) ) { echo " selected='selected' "; } ?>>
    					   <?php echo( $opTitle ); ?>
    				    </option>       
                        <?php } ?>
                    </optgroup>
                    <?php }else { ?>
    				<option value="<?php echo( $value ); ?>"<?php if( in_array( $value, $args['value'] ) ) { echo " selected='selected' "; } ?>>
    					<?php echo( $title ); ?>
    				</option>
                    <?php } ?>
    			<?php } ?>
            </select>
            <?php
        }
        
        /**
         * Print Checkbox Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_checkbox( $args = array() )
        {
            if ( ! array_key_exists( 'options', $args ) ) {
                    $args['options'] = array();
            }
            if ( ! array_key_exists( 'color', $args ) || $args['color'] != 'orange' ) {
                    $args['color'] = 'blue';
            }
            if( ! $args['value'] || ! is_array( $args['value'] ) ) {
                $args['value'] = array();
            }
            foreach ( $args['options'] as $value => $title ) {
            ?>
            <label class="checkbox">
				<input name="<?php echo $args['id'];?>[]" type="checkbox" class="icheck-<?php echo( $args['color'] ); ?><?php if( $args['class'] ) { echo( $args['class'] ); } ?>" value="<?php echo( $value ); ?>" <?php if( $args['attr'] ) { echo( $args['attr'] ); } ?><?php if( in_array( $value, $args['value'] ) ) { echo " checked='checked'"; } ?>/>
				<span><?php echo( $title ); ?></span>
			</label>
            <?php
            }
        }
        
        /**
         * Print Radio Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_radio( $args = array() )
        {
            if ( ! array_key_exists( 'options', $args) ) {
                    $args['options'] = array();
            }
            if ( ! array_key_exists('color', $args) || $args['color'] != 'orange' ) {
                    $args['color'] = 'blue';
            }
            if( ! $args['value'] || ! is_array($args['value'] ) ) {
                $args['value']= array();
            }
            foreach ( $args['options'] as $value => $title ) {
            ?>
            <label class="checkbox">
				<input name="<?php echo $args['id'];?>[]" type="radio" class="icheck-<?php echo( $args['color'] ); ?><?php if( $args['class'] ) { echo( $args['class'] ); } ?>" value="<?php echo( $value ); ?>" <?php if( $args['attr'] ) { echo( $args['attr'] ); } ?><?php if( in_array( $value, $args['value'] ) ){ echo " checked='checked'" ; } ?>/>
				<span><?php echo( $title ); ?></span>
			</label>
            <?php
            }
        }
        
        /**
         * Print Color Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_color( $args = array() )
        {
            $hex = isset( $args['value']['hex'] )? $args['value']['hex']: '';
            $styleColor = isset( $args['value']['hex'] )? CPJ_Tools::invertColor( $args['value']['hex'] ) : 'rgb(67, 67, 67)';
            $styleBackground = isset( $args['value']['hex'] )? $args['value']['hex'] : 'rgb(247, 247, 247)';
            ?>
            <div>
            <input name="<?php echo $args['id']; ?>[hex]" style="background-color: <?php echo $styleBackground; ?>;color: <?php echo $styleColor; ?>;" value="<?php echo isset( $args['value']['hex'] )? $args['value']['hex'] : ''; ?>" class="form-control input-color<?php if( $args['class'] ) { echo( $args['class'] ); } ?>" data-opacity="<?php echo isset( $args['value']['opacity'] )? $args['value']['opacity'] : ''; ?>" <?php if( $args['attr'] ) { echo( $args['attr'] ); } ?>/>
            <input name="<?php echo $args['id']; ?>[rgb]" <?php echo isset( $args['value']['rgb'] )? 'value="'.$args['value']['rgb'] . '"' : ''; ?> class="form-control hidden input-color-rgb" />
            <input name="<?php echo $args['id']; ?>[rgba]" value="<?php echo isset( $args['value']['rgba'] )? $args['value']['rgba'] : ''; ?>" class="form-control hidden input-color-rgba" />
            <input name="<?php echo $args['id']; ?>[opacity]" value="<?php echo isset( $args['value']['opacity'] )? $args['value']['opacity'] : ''; ?>" class="form-control hidden input-color-opacity" />
            </div>
            <?php
        }
        
        /**
         * Print Media Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_media( $args = array() )
        {
            if ( ! array_key_exists( 'library', $args ) ) {
                    $args['library'] = 'false';
            }
            if ( ! array_key_exists('uploader-title', $args ) ) {
                    $args['uploader-title'] = __( "Choose File(s)", "post-page-manager" );
            }
            if ( ! array_key_exists( 'uploader-button', $args ) ) {
                    $args['uploader-button'] = __( "Insert File(s)", "post-page-manager" );
            }
            if ( ! array_key_exists( 'button-text', $args ) ) {
                    $args['button-text'] = __( "Change File(s)", "post-page-manager" );
            }
            if( ! $args['value'] ) {
                $args['value'] = "";
            }
            ?>
            <div class="upload_media">
                <input name="<?php echo $args['id']; ?>" value="<?php echo $args['value']; ?>" class="form-control" type="hidden" />
    			<button class="btn btn-sm btn-primary" data-type="<?php echo( $args['library'] ); ?>" <?php if( $args['multiple'] ) { echo( 'data-multiple="true" ' ); } ?>data-preview="true" data-uploader-title="<?php echo( $args['uploader-title'] ); ?>" data-uploader-button-text="<?php echo( $args['uploader-button'] ); ?>">
                    <?php echo( $args['button-text'] ); ?>
                </button>
                <?php if( $args['multiple']){ ?>
                <span class="multi-note"><small><?php _e('Hold', 'cpj'); ?> <kbd>ctrl</kbd> <?php _e('key for multiselect', 'cpj'); ?></small></span>
                <?php } ?>
                <div class="upload_preview top-7">
                    <ul class="select-media-sortable">
                    <?php if( ! empty( $args['value'] ) ) { ?>
                       <?php $ids = explode( ',', $args['value'] );?>
                       <?php foreach( $ids as $id ) { ?>
                        <?php $attachment = get_post( $id ); ?>
                            <?php if( $args['library'] =='image'){ ?>
                                <li class="image" data-id="<?php echo( $id ); ?>"><a href="<?php echo $attachment->guid; ?>" target="_blank"><div class="media-sortable-remove" data-id="<?php echo( $id ); ?>"></div><img src="<?php echo wp_get_attachment_thumb_url( $id ); ?>" width="100" height="100" class="img-responsive img-thumbnail select-img-thumbnail" alt="<?php echo $attachment->post_title; ?>" /></a></li>
                            <?php }else { ?>
                                <li class="other" data-id="<?php echo( $id ); ?>"><a href="<?php echo $attachment->guid; ?>" target="_blank"><div class="media-sortable-remove" data-id="<?php echo( $id ); ?>"></div><?php echo $attachment->post_title; ?></a></li>
                            <?php } ?>
                       <?php }?>
                    <?php }else { ?>
                    <li><?php _e( 'There is no selected items.', 'post-page-manager' ); ?></li>
                    <?php } ?>
                    </ul>
                </div>
            </div>
            <?php
        }
        
        /**
         * Print Typography Field HTML code.
         * 
         * @since 1.0.0
         * 
         * @param array $args   An array of arguments.
         */ 
        public static function field_typography( $args = array() )
        {
            ?>
            <div class="row">
                <div class="col-md-6">
                    <small><strong><?php _e( 'Font Family', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[family]',
                                            'type'          =>  'select',
                                            'placeholder'   =>  'select Google Font',
                                            'options'       =>  array_merge( $GLOBALS['cpj_webSafeFonts'], $GLOBALS['cpj_gFontsByCategory'] ),
                                            'class'         =>  'chosen-gfonts-select',
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['family'] )?
                                                                $args['value']['family'] : array(),
                                            )); ?>
                </div>
                <div class="col-md-6 chosen-gfonts-backup"<?php if( ! isset( $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['subsets'] ) ) { echo(' style="display:none"' ); } ?>>
                    <small><strong><?php _e( 'Web Safe Font (Backup)', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[safe-font]',
                                            'type'          =>  'select',
                                            'options'       =>  $GLOBALS['cpj_webSafeFonts'],
                                            'class'         =>  'typo-safe-font',
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['safe-font'] )?
                                                                $args['value']['safe-font'] : array(),
                                            )); ?>
                </div>
                <div class="col-md-6">
                    <small><strong><?php printf( __('Font Weight %s Style', 'cpj'), "&amp;" ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[variants]',
                                            'type'          =>  'select',
                                            'placeholder'   =>  'select Variants',
                                            'class'         =>  'chosen-gfonts-variants',
                                            'columns'       =>  'none',
                                            'options'       =>  isset( $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['variants'] )?
                                                                $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['variants'] : array(
                                                                                                                                                    'normal'    => 'Normal',
                                                                                                                                                    'italic'    => 'Normal Italic',
                                                                                                                                                    'bold'      => 'Bold',
                                                                                                                                                    'bolditalic'=> 'Bold Italic',
                                                                                                                                                    ),
                                            'value'         =>  isset( $args['value']['variants'] )?
                                                                $args['value']['variants'] : array(),
                                            )); ?>
                    <select class="web-safe-font-variants hidden">
                        <option value="normal"><?php _e( 'Normal', 'post-page-manager' ); ?></option>
                        <option value="italic"><?php _e( 'Normal Italic', 'post-page-manager' ); ?></option>
                        <option value="bold"><?php _e( 'Bold', 'post-page-manager' ); ?></option>
                        <option value="bolditalic"><?php _e( 'Bold Italic', 'post-page-manager' ); ?></option>
                    </select>
                    <input class="typo-font-style" type="hidden" value="<?php echo isset($args['value']['font-style'])?$args['value']['font-style']:'normal'; ?>" name="<?php echo $args['id'];?>[font-style]" />
                    <input class="typo-font-weight" type="hidden" value="<?php echo isset($args['value']['font-weight'])?$args['value']['font-weight']:'normal'; ?>" name="<?php echo $args['id'];?>[font-weight]" />
                </div>
                <div class="col-md-6"<?php if( ! isset( $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['subsets'] ) ) { echo( ' style="display:none"' ); } ?>>
                    <small><strong><?php _e('Font Subsets', 'cpj'); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[subsets]',
                                            'type'          =>  'select',
                                            'placeholder'   =>  'select Subsets',
                                            'class'         =>  'chosen-gfonts-subsets',
                                            'options'       =>  isset( $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['subsets'] )?
                                                                $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['subsets'] : array(),
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['subsets'] )?
                                                                $args['value']['subsets'] : array(),
                                            )); ?>
                </div>
                <?php if( array_key_exists( 'text-align', $args ) && $args['text-align'] === true ) { ?>
                <div class="col-md-3">
                    <small><strong><?php _e( 'Text Align', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'] . '[text-align]',
                                            'type'          =>  'select',
                                            'placeholder'   =>  'select Align',
                                            'class'         =>  'typo-text-align',
                                            'columns'       =>  'none',
                                            'options'       =>  array(
                                                                'left'      =>  'Left',
                                                                'right'     =>  'Right',
                                                                'center'    =>  'Center',
                                                                'justify'   =>  'Justify',
                                                                'initial'   =>  'Initial',
                                                                'inherit'   =>  'Inherit',
                                                                ),
                                            'value'         =>  isset( $args['value']['text-align'] )?
                                                                $args['value']['text-align'] : array(),
                                            )); ?>
                </div>
                <?php } ?>
                <?php if ( array_key_exists( 'font-size', $args ) && $args['font-size'] === true ) { ?>
                <div class="col-sm-3">
                    <small><strong><?php _e( 'Font Size (px)', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[font-size]',
                                            'type'          =>  'number',
                                            'class'         =>  'typo-property',
                                            'attr'          =>  array(
                                                                'data-typo' =>  'font-size',
                                                                ),
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['font-size'] )?
                                                                $args['value']['font-size'] : '',
                                            )); ?>
                </div>
                <?php } ?>
                <?php if( array_key_exists( 'line-height', $args ) && $args['line-height'] === true ) { ?>
                <div class="col-sm-3">
                    <small><strong><?php _e( 'Line Height (px)', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[line-height]',
                                            'type'          =>  'number',
                                            'class'         =>  'typo-property',
                                            'attr'          =>  array(
                                                                'data-typo' => 'line-height',
                                                                ),
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['line-height'] )?
                                                                $args['value']['line-height'] : '',
                                            )); ?>
                </div>
                <?php } ?>
                <?php if( array_key_exists( 'word-spacing', $args ) && $args['word-spacing'] === true ) { ?>
                <div class="col-sm-3">
                    <small><strong><?php _e('Word Spacing (px)', 'cpj'); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[word-spacing]',
                                            'type'          =>  'number',
                                            'class'         =>  'typo-property',
                                            'attr'          =>  array(
                                                                'data-typo' => 'word-spacing',
                                                                ),
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['word-spacing'] )?
                                                                $args['value']['word-spacing'] : '',
                                            )); ?>
                </div>
                <?php } ?>
                <?php if( array_key_exists( 'letter-spacing', $args ) && $args['letter-spacing'] === true ) { ?>
                <div class="col-sm-3">
                    <small><strong><?php _e( 'Letter Spacing (px)', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[letter-spacing]',
                                            'type'          =>  'number',
                                            'class'         =>  'typo-property',
                                            'attr'          =>  array(
                                                                'data-typo' => 'letter-spacing',
                                                                ),
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['letter-spacing'] )?
                                                                $args['value']['letter-spacing'] : '',
                                            )); ?>
                </div>
                <?php } ?>
                <?php if( array_key_exists('color', $args) && $args['color'] === true) { ?>
                <div class="col-sm-3">
                    <small><strong><?php _e( 'Color', 'post-page-manager' ); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'].'[color]',
                                            'type'          =>  'color',
                                            'class'         =>  'typo-font-color',
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['color'] )?
                                                                $args['value']['color'] : array(
                                                                                            'hex'    =>  '',
                                                                                            'rgba'   =>  '',
                                                                                            'rgb'    =>  '',
                                                                                            'opacity'=>  '',
                                                                                            ),
                                            )); ?>
                </div>
                <?php } ?>
                <div class="col-sm-6 typo-font-text-div"<?php if( ! isset( $GLOBALS['cpj_gFontsByFamily'][ $args['value']['family'][0] ]['subsets'] ) ) { echo( ' style=" display:none"' ); } ?>>
                    <small><strong><?php _e('Characters to load (text)', 'cpj'); ?></strong></small>
                    <?php self::field(array('id'            =>  $args['id'] . '[google-text]',
                                            'type'          =>  'text',
                                            'class'         =>  'typo-font-text',
                                            'columns'       =>  'none',
                                            'value'         =>  isset( $args['value']['google-text'] )?
                                                                $args['value']['google-text'] : '',
                                            )); ?>
                </div>
                <?php
                $previewStyle = "";
                $familyBackup = isset( $args['value']['safe-font'][0] )? ',' . $args['value']['safe-font'][0] : '';
                $previewStyle .= isset( $args['value']['family'][0] )? 'font-family: ' . $args['value']['family'][0] . $familyBackup . ';' : '';
                $previewStyle .= isset( $args['value']['text-align'][0] )? 'text-align: ' . $args['value']['text-align'][0] . ';' : '';
                $previewStyle .= isset( $args['value']['font-style'] )? 'font-style: ' . $args['value']['font-style'] . ';' : '';
                $previewStyle .= isset( $args['value']['font-weight'] )? 'font-weight: ' . $args['value']['font-weight'] . ';' : '';
                $previewStyle .= isset( $args['value']['font-size'] )? 'font-size: ' . $args['value']['font-size'] . 'px;' : '';
                $previewStyle .= isset( $args['value']['line-height'] )? 'line-height: ' . $args['value']['line-height'] . 'px;' : '';
                $previewStyle .= isset( $args['value']['word-spacing'] )? 'word-spacing: ' . $args['value']['word-spacing'] . 'px;' : '';
                $previewStyle .= isset( $args['value']['letter-spacing'] )? 'letter-spacing: ' . $args['value']['letter-spacing'] . 'px;' : '';
                $previewStyle .= isset( $args['value']['color']['hex'] )? 'color: ' . $args['value']['color']['hex'] . ';' : '';
                ?>
                <div class="col-sm-12" style="font-size: 18px;line-height: 1.4;">
                    <div class="typo-font-preview" style="display: none;<?php echo $previewStyle; ?>">
                        A B C D E F G H I J K L M N O P Q R S T U V W X Y Z <br /> a b c d e f g h i j k l m n o p q r s t u v w x y z <br /> 1 2 3 4 5 6 7 8 9 0
                    </div>
                </div>
            </div>
            <?php
        }
        
        /**
         * Text Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function text( $args = array() )
        {
            $args['type'] = 'text';
            self::field( $args );
        }
        
        /**
         * Texarea Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function textarea( $args = array() )
        {
            $args['type'] = 'textarea';
            self::field( $args );
        }
        
        /**
         * Number Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function number( $args = array() )
        {
            $args['type'] = 'number';
            self::field( $args );
        }
        
        /**
         * Toggle Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function toggle( $args = array() )
        {
            $args['type'] = 'toggle';
            self::field( $args );
        }
        
        /**
         * Code Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function code( $args = array() )
        {
            $args['type'] = 'code';
            self::field( $args );
        }
        
        /**
         * Select Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function select( $args = array() )
        {
            $args['type'] = 'select';
            self::field( $args );
        }
        
        /**
         * Checkbox Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function checkbox( $args = array() )
        {
            $args['type'] = 'checkbox';
            self::field( $args );
        }
        
        /**
         * Radio Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function radio( $args = array() )
        {
            $args['type'] = 'radio';
            self::field( $args );
        }
        
        /**
         * Color Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function color( $args = array() )
        {
            $args['type'] = 'color';
            self::field( $args );
        }
        
        /**
         * Media Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function media( $args = array() )
        {
            $args['type'] = 'media';
            self::field( $args );
        }
        
        /**
         * Typography Field
         * 
         * @since 1.0.0
         * @param array $args   An array of arguments.
         */
        public static function typography( $args = array() )
        {
            $args['type'] = 'typography';
            self::field( $args );
        }
    }
    new ZMX_Form();
}