<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

 
/**
 * Call ZMX_Options_Metabox class on the post add/edit screen.
 */
function call_ZMX_Options_Metabox()
{
    new ZMX_Options_Metabox();
}

/**
 * Hook into the appropriate actions and call ZMX_Options_Metabox class
 * after checking the following points:
 * 
 * 1- Theme supports cpj framework.
 * 2- User can manage options.
 * 3- Current post type support cpj options metabox.
 * 4- It is a add new or edit post page.
 */
function load_ZMX_Options_Metabox()
{
    if ( current_theme_supports( 'cpj-framework' ) && current_user_can( 'manage_options' ) &&  is_array( $GLOBALS['cpj_config']['templates'] ) )
    {
        add_action( 'load-post.php', 'call_ZMX_Options_Metabox' );
        add_action( 'load-post-new.php', 'call_ZMX_Options_Metabox' );
        add_action( 'wp_ajax_metaboxTemsUpdate',  array( 'ZMX_Options_Metabox', 'metabox_templates_action' ) );
    }
}
add_action( 'after_setup_theme', 'load_ZMX_Options_Metabox' );

/**
 * Zomax Options Metabox class.
 *
 * Add metabox to post add/edit page, save options with post update.
 *
 * @since 1.0.0
 *
 * @see ZMX_Options_Metabox
 */
if ( ! class_exists( 'ZMX_Options_Metabox' ) )
{
    class ZMX_Options_Metabox
    {
        /**
         * Hook into the appropriate actions when the class is constructed.
         */
        public function __construct()
        {
            $this->adminOpName = isset($GLOBALS['cpj_config']['options-name']) ? $GLOBALS['cpj_config']['options-name'] : __('Zomax Options');
            $this->templates = $GLOBALS['cpj_config']['templates'];
            $this->_panels = $GLOBALS['cpj_config']['_panels'];
            add_action('add_meta_boxes', array($this, 'add_meta_box') );
            add_action('save_post', array($this, 'save') );
        }
        
        static function metabox_templates_action()
        {
            if ( ! isset( $_POST['templatesManNextNonce'] ) || !wp_verify_nonce($_POST['templatesManNextNonce'], 'cpj-next-nonce' ) )
            {
                CPJ_Tools::notify( 'danger', __( "Security Error", "post-page-manager" ), __( "Sorry, your nonce did not verify.", "post-page-manager" ), "15000" );
            } else
            {
                $_POST['v'] = CPJ_Tools::array_remove_empty_deep( $_POST['v'] );
                
                foreach( $_POST['v'] as $key => $value )
                {
                    if( CPJ_Tools::select_template( $key, $_POST['key'], true ) == $_POST['v'][ $key ] )
                        unset( $_POST['v'][ $key ] );
                }
                
                if ( update_post_meta( $_POST['key'], 'cpj_templates', $_POST['v'] ) )
                {
                    CPJ_Tools::notify( 'success', __( "Well Done!", "post-page-manager" ), __( "Templates & templates options updated successfully.", "post-page-manager" ), "8000" );
                } else
                {
                    CPJ_Tools::notify( 'warning', __( "Somthing Error!", "post-page-manager" ), __("There's no changes made to template options.", "post-page-manager" ), "15000" );
                }
            }
            self::zmx_meta_options_tabs( $_POST['key'] );
            die();
        }
        
        public function meta_box_scripts()
        {       
                CPJ_Tools::enqueue_style( 'bootstrap-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootstrap/bootstrap-zmx.min.css', false, '3.2.0' );
                CPJ_Tools::enqueue_script( 'bootstrap_js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootstrap/bootstrap.min.js', array(), '3.2.0', true );
                CPJ_Tools::enqueue_style( 'bootflat-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootflat/css/bootflat-zmx.min.css', false, '2.0.2' );
                CPJ_Tools::enqueue_script( 'icheck-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootflat/js/icheck.min.js', array(), '1.0.1', true );
                wp_enqueue_style( 'font-awesome', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/font-awesome/css/font-awesome.min.css', true, '4.3.0' );
                CPJ_Tools::enqueue_script( 'jquery-notify', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/jquery-notify/src/jquery.notify.min.js', array(), '1.5', true );
                CPJ_Tools::enqueue_script( 'stepper-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootflat/js/jquery.fs.stepper.min.js', array(), '3.0.7', true );
                CPJ_Tools::enqueue_script( 'selecter-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/selecter/jquery.fs.selecter.min.js', array(), '3.1.9', true );
                CPJ_Tools::enqueue_script( 'bootstrap-confirmation', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/bootstrap-confirmation/bootstrap-confirmation.js', array(), '1.0.0', true );
                CPJ_Tools::enqueue_script( 'jquery-chosen-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/jquery-chosen/chosen.jquery.min.js', array( 'jquery' ), '1.1.0', true );
                CPJ_Tools::enqueue_style( 'jquery-chosen-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/jquery-chosen/chosen-bootstrap.min.css', false, false );
                CPJ_Tools::enqueue_script( 'jquery-minicolors-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/minicolors/jquery.minicolors.min.js', array( 'jquery' ), '1.1.0', true );
                CPJ_Tools::enqueue_style( 'jquery-minicolors-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/minicolors/jquery.minicolors.css', false, false );
                wp_enqueue_script( 'jquery-lazyload', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/lazyload/jquery.lazyload.min.js', array(), '1.9.5', true );
                CPJ_Tools::enqueue_script( 'ace-editor', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/ace-editor/ace.js', array(), '1.1.6', true );
                CPJ_Tools::enqueue_script( 'ace-auto-complete', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/ace-editor/ext-language_tools.js', array(), '1.1.6', true );
                
    			wp_dequeue_style( 'jquery-chosen' );
    			wp_dequeue_script( 'jquery-chosen' );
                
                // Enqueue Zomax Panels Custom Styles & Scripts.
                CPJ_Tools::enqueue_style( 'cpj-css', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/cpj/cpj-zmx.min.css', array(
                                                                                                            'bootstrap-css',
                                                                                                            'bootflat-css',
                                                                                                            'jquery-chosen-css',
                                                                                                            'jquery-minicolors-css',
                                                                                                            ), POST_PAGE_MANAGER_VERSION );
                CPJ_Tools::enqueue_script( 'cpj-js', POST_PAGE_MANAGER_PLUGIN_URL . 'assets/cpj/cpj.min.js', array(
                                                                                                            'jquery',
                                                                                                            'bootstrap_js',
                                                                                                            'jquery-notify',
                                                                                                            'icheck-js',
                                                                                                            'selecter-js',
                                                                                                            'stepper-js',
                                                                                                            'bootstrap-confirmation',
                                                                                                            'jquery-chosen-js',
                                                                                                            'jquery-minicolors-js',
                                                                                                            'jquery-lazyload',
                                                                                                            'ace-editor',
                                                                                                            'ace-auto-complete',
                                                                                                            ), POST_PAGE_MANAGER_VERSION, true );
                
                wp_localize_script( 'cpj-js', "cpjTranslate", array(
                                                                        'adminOpId'             =>  CPJ_Tools::generateId( $this->adminOpName ),
                                                                        'googleFontsByFamily'   =>  json_encode( $GLOBALS['cpj_gFontsByFamily'] ),
                                                                        'googleFontsApiLink'    =>  'http://fonts.googleapis.com/css',
                                                                        'chosenNoResult'        =>  __( 'Oops, nothing found!', 'post-page-manager' ),
                                                                        'chosenSelectMulti'     =>  __( 'Select Some Options!', 'post-page-manager' ),
                                                                        'chosenSelectSingle'    =>  __( 'Select an Option', 'post-page-manager' ),
                                                                        'enterFullscreen'       =>  __( 'Fullscreen On', 'post-page-manager' ),
                                                                        'exitFullscreen'        =>  __( 'Fullscreen Off', 'post-page-manager' ),
                                                                        'left'                  =>  ( is_rtl())? 'right' : 'left',
                                                                        'right'                 =>  ( is_rtl() )? 'left' : 'right',
                                                                        'press'                 =>  __( 'Press', 'post-page-manager' ),
                                                                        'forWord'               =>  __( 'for', 'post-page-manager' ),
                                                                        'autocompletion'        =>  __( 'Autocompletion', 'post-page-manager' ),
                                                                        'space'                 =>  __( 'Space', 'post-page-manager' ),
                                                                        'search'                =>  __( 'Search', 'post-page-manager' ),
                                                                        'and'                   =>  __( 'and', 'post-page-manager' ),
                                                                        'replace'               =>  __( 'Replace', 'post-page-manager' ),
                                                                        )
                                                                        );
                foreach( $this->_panels as $key => $value ) {
                    if( $value['type'] == 'builtin' ) {
                        CPJ_Tools::enqueue_script( $value['key'] . '-javascript', POST_PAGE_MANAGER_PLUGIN_URL . 'panels/'. $value['key'] .'/javascript.js', array( 'cpj-js' ), POST_PAGE_MANAGER_VERSION, true, false );
                    }else {
                        CPJ_Tools::enqueue_script( $value['key'] . '-javascript', get_template_directory_uri() . '/panels/'. $value['key'] .'/javascript.js', array( 'cpj-js' ), POST_PAGE_MANAGER_VERSION, true, false );
                    }
                }
        }
    
        /**
         * Remove Visual Composer Scripts Cause Conflict.
         */
        public function remove_vc_scripts()
        {
    			wp_dequeue_script( 'vc_bootstrap_js_1' );
    			wp_dequeue_script( 'vc_bootstrap_js_2' );
    			wp_dequeue_script( 'vc_bootstrap_js_11' );
        }
    
        /**
         * Adds the meta box container.
         */
        public function add_meta_box( $post_type )
        {
            // at this step you could direct post dependens on Post Type
            $post_types_array = array(
                                'page',
                                'post',
                                'attachment',
                                'product',
                                'essential_grid',
                                );
            if ( in_array( $post_type, $post_types_array ) || ( isset( $GLOBALS['cpj_options']['cpj_post_types'][ $post_type ]['supports'] ) && in_array( 'cpj', $GLOBALS['cpj_options']['cpj_post_types'][ $post_type ]['supports'] ) ) )
            {
                add_action( 'admin_enqueue_scripts', array($this, 'meta_box_scripts') );
                add_action( 'admin_print_scripts-post.php', array($this, 'remove_vc_scripts') );
                add_action( 'admin_print_scripts-post-new.php', array($this, 'remove_vc_scripts') );
                add_meta_box( CPJ_Tools::generateId( $this->adminOpName ) , $this->adminOpName, array( $this, 'render_meta_box_content' ), $post_type, 'normal', 'core' );
            }
        }
    
        /**
         * Save the meta when the post is saved.
         *
         * @param int $post_id The ID of the post being saved.
         */
        public function save( $post_id )
        {
            if ( ! isset( $_POST['templatesManNextNonce'] ) )
                return $post_id;
    
            $nonce = $_POST['templatesManNextNonce'];
    
            if ( ! wp_verify_nonce( $nonce, 'cpj-next-nonce') )
                return $post_id;
    
            if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
                return $post_id;
                
            if ( 'page' == $_POST['post_type'] )
            {
                if ( ! current_user_can( 'edit_page', $post_id ) )
                    return $post_id;
            } else
            {
                if ( ! current_user_can( 'edit_post', $post_id ) )
                    return $post_id;
            }
            $cpjOptions = array();
            $cpjOptions['general'] = isset( $_POST['general'] )? $_POST['general'] : array();
            foreach ( $cpjOptions['general'] as $k => $v )
            {
                $default = CPJ_Tools::get_option( "general/". $k, null, "default" );
                if( wp_unslash( $v ) == $default )
                {
                    unset( $cpjOptions['general'][ $k ] );
                }
            }
                
            //$this_templates = unserialize( base64_decode( $_POST['cpj_selected_templates'] ) );
            $values = array();
            foreach( $GLOBALS['cpj_config']['templates'] as $group_key => $group_value )
            {
                foreach ( $group_value as $tempK => $tempV )
                {
                    if( ! empty( $tempV ) )
                    {
                        $values[] = $tempK;
                    }
                }
            }
            foreach ( $values as $value )
            {
                $optionsArray = isset( $_POST[ $value . "_options"] )? $_POST[ $value . "_options"] : array();
                foreach ( $optionsArray as $k => $v )
                {
                    $default = CPJ_Tools::get_option( $value ."_options/". $k, null, "DEFAULT" );
                    if( wp_unslash( $v ) == $default  )
                    {
                        unset( $optionsArray[ $k ] );
                    }
                }
                if( ! empty( $optionsArray ) )
                    $cpjOptions[ $value . "_options"] = $optionsArray;
            }
            // Update the meta field.
            delete_post_meta( $post_id, 'cpj_options' );
            add_post_meta( $post_id, 'cpj_options', $cpjOptions );
        }
    
        /**
         * Render Post Meta Box content.
         *
         * @param WP_Post $post The post object.
         */
        public function render_meta_box_content( $post )
        {
            ?>
            <div class="zmx">
                <?php $this->templates_meta_modal( $post->ID ); ?>
                <div class="row">
                	<div class="col-md-6">
                		<h4>
                			<?php _e( "Templates Options", "post-page-manager" ); ?>
                		</h4>
                	</div>
                	<div class="col-md-6 text-right">
                		<!-- Add Link trigger modal -->
                		<a class="btn btn-primary top-7" data-toggle="modal-post" data-target="#selectTemplateModal">
                			<i class='glyphicon glyphicon-th-large'>
                			</i>
                			<?php _e( "Customize Templates", "post-page-manager" ); ?>
                		</a>
                	</div>
                </div>
                <div class="panel panel-fullwidth-12" id="zmxMetaOptionsTabs">
                    <?php self::zmx_meta_options_tabs( $post->ID ); ?>
                </div>
                
                <div class="ajax-waiting text-center v-center"></div>
                
                <!-- .cpj-container -->
                <div class="cpj-notify-container col-md-3">
                    <div id="success" class="alert alert-success cpj-notify">
                		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                        <h4>#{title}</h4>
                		#{msg}
                	</div>
                    <div id="danger" class="alert alert-danger cpj-notify">
                		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                        <h4>#{title}</h4>
                		#{msg}
                	</div>
                    <div id="warning" class="alert alert-warning cpj-notify">
                		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                        <h4>#{title}</h4>
                		#{msg}
                	</div>
                    <div id="info" class="alert alert-info cpj-notify">
                		<button type="button" class="close ui-notify-close" aria-hidden="true">&times;</button>
                        <h4>#{title}</h4>
                		#{msg}
                	</div>
                </div>
                <!-- #cpj-notify-container -->
            </div>
            <?php
        }
        
        static function zmx_meta_options_tabs( $post_ID )
        {
            ?>
            <!-- Nav tabs -->
            <ul class="nav nav-tabs nav-justified" role="tablist">
                <li role="presentation" class="active"><a href="#general" role="tab" data-toggle="tab"><?php _e("General", "cpj"); ?></a></li>
                <?php
                foreach( $GLOBALS['cpj_config']['templates'] as $key => $value )
                {
                    $templateKey = explode( '#', $key );
                    if( $templateKey[2] == 'single' )
                    {
                        echo '<li role="presentation"><a href="#' . $templateKey[1] . '-tab" role="tab" data-toggle="tab">' . $templateKey[0] . '</a></li>';
                    } else
                    {
                        $current_template = CPJ_Tools::select_template( $templateKey[1], $post_ID );
                        
                        echo '<li class="dropdown">';
                        echo '<a href="#" id="' . $templateKey[1] . '" class="dropdown-toggle" data-toggle="dropdown">' . $templateKey[0] . '<span class="caret"></span></a>';
                        echo '<ul class="dropdown-menu" role="menu">';
                            echo '<li><a href="#' . $current_template . '-tab" tabindex="-1" data-toggle="tab">' . $value[ $current_template ] . ' (' . __( 'selected', 'post-page-manager' ) . ')</a></li>';
                            unset( $value[ $current_template ] );
                            foreach ( $value as $k => $v )
                            {
                                if( ! empty( $v ) )
                                {
                                echo '<li><a href="#' . $k . '-tab" tabindex="-1" data-toggle="tab">' . $v . '</a></li>';
                                }
                            }
                        echo '</ul></li>';
                    }
                    
                }
                ?>
            </ul>
            <!-- Tab panes -->
            <div class="tab-content">
                <div role="tabpanel" class="tab-pane active" id="general">
                    <?php do_action( 'general_meta_options', $post_ID ); ?>
                </div>
                <?php
                $post_templates = array();
                foreach( $GLOBALS['cpj_config']['templates'] as $key => $value )
                {
                    $templateKey = explode( '#', $key );
                    $template_to_display = CPJ_Tools::select_template( $templateKey[1], $post_ID );
                    $post_templates[ $templateKey[1] ] = $template_to_display;
                    
                    if( $templateKey[2] == 'single' )
                    {
                    ?>
                    <div role="tabpanel" class="tab-pane" id="<?php echo $templateKey[1]; ?>-tab">
                        <h5 class="text-primary"><?php printf( __( '%s %sTemplate Options%s', 'boss__theme' ), $value[ $template_to_display ], '<small class="text-danger">', '</small>' ); ?></h5><hr />
                        <?php do_action( $template_to_display . '_meta_options', $post_ID ) ?>
                    </div>
                    <?php
                    } else
                    {
                        foreach ( $value as $k => $v )
                        {
                            if( ! empty( $v ) )
                            {
                            ?>
                            <div role="tabpanel" class="tab-pane" id="<?php echo $k; ?>-tab">
                                <h5 class="text-primary"><?php printf( __( '%s %sTemplate Options%s', 'boss__theme' ), $v, '<small class="text-danger">', '</small>' ); ?></h5><hr />
                                <?php do_action( $k . '_meta_options', $post_ID ) ?>
                            </div>
                            <?php
                            }
                        }
                    }
                }
                ?>
            </div>
            <div class="row hidden">
            	<div class="col-md-12">
            		<textarea class="form-control" id="cpj_templates_arr"><?php echo json_encode( $post_templates ); ?></textarea>
                    <textarea class="form-control" name="cpj_selected_templates"><?php echo base64_encode( serialize( $post_templates ) ); ?></textarea>
            	</div>
            </div>
            <?php
        }
        
        public function templates_meta_tabs_list( $key, $templatesArray )
        {
             $templateKey = explode( '#', $key );
        ?>
        <div class="row">
        	<div class="col-lg-9 col-md-9 col-sm-12 col-xs-12 templates-items-wrapper" id="<?php echo $templateKey[1]; ?>-select-box">
        		<div class="col-lg-3 col-md-4 col-sm-6 col-xs-12 padding-3" id="<?php echo $templateKey[1]; ?>-select-preview">
                  <div class="templates-thumbnail select-template-item" data-key="<?php echo $templateKey[1]; ?>" data-folder="">
    			     <img class="img-rounded img-responsive center-block" alt="<?php _e( "No Screenshot Available", "post-page-manager" ); ?>" data-original="<?php echo POST_PAGE_MANAGER_PLUGIN_URL . 'panels/zmx_templates_man/no-screenshot/285x220.png'; ?>" />
    			     <p>
    			         <?php _e( "Default Template", "post-page-manager" ); ?>
                    </p>
                    <div class="template-description"></div>
                  </div>
    			</div>
                <?php
                foreach ( $templatesArray as $folder => $name )
                {
                    if( ! empty( $folder ) )
                    {
                    ?>
        			<div class="col-lg-3 col-md-4 col-sm-6 col-xs-12 padding-3">
                      <div class="templates-thumbnail select-template-item" data-key="<?php echo $templateKey[1]; ?>" data-folder="<?php echo $folder; ?>">
                        <?php if ( locate_template( 'templates/' . $folder . '/screenshots/285x220.png' ) != '' ) { ?>
        				<img class="img-rounded img-responsive center-block" alt="<?php echo $name; ?> template screenshot" data-original="<?php echo get_template_directory_uri() . '/templates/' . $folder . '/screenshots/285x220.png'; ?>" />
                        <?php }else { ?>
        				<img class="img-rounded img-responsive center-block" alt="<?php _e( "No Screenshot Available", "post-page-manager" ); ?>" data-original="<?php echo POST_PAGE_MANAGER_PLUGIN_URL . 'panels/zmx_templates_man/no-screenshot/285x220.png'; ?>" />
                        <?php } ?>
                        <p>
                            <?php
                                echo $name;
                            ?>
        				</p>
                        <div class="template-description hidden">
                            <?php get_template_part( 'templates/' . $folder . '/readme' ); ?>
                        </div>
                      </div>
        			</div>
        			<?php
                    }
                }
                ?>
                <?php if( isset( $GLOBALS['cpj_config']['add-new-url'] ) && trim( $GLOBALS['cpj_config']['add-new-url'] ) != '' ) { ?>
                <div class="col-lg-3 col-md-4 col-sm-6 col-xs-12 padding-3">
                  <div class="templates-thumbnail add-new-template" data-url="<?php echo $GLOBALS['cpj_config']['add-new-url']; ?>" >
        		     <img class="img-rounded img-responsive center-block" alt="<?php echo __( "Add New", "post-page-manager" ) . ' ' . $templateKey[0]; ?>" data-original="<?php echo POST_PAGE_MANAGER_PLUGIN_URL . 'panels/zmx_templates_man/add-new/285x220.png'; ?>" />
        		     <p>
        		         <?php echo __( "Add / Duplicate", "post-page-manager" ) . ' ' . $templateKey[0]; ?>
                    </p>
                  </div>
        		</div>
                <?php } ?>
        	</div>
        	<div class="col-lg-3 col-md-3 hidden-sm hidden-xs templates-items-wrapper template-preview-tab">
        		<img class="img-responsive img-thumbnail center-block" alt="No Screenshot" src="<?php echo POST_PAGE_MANAGER_PLUGIN_URL . '/panels/zmx_templates_man/no-screenshot/285x220.png'; ?>" />
                <h4 class="text-center">Not Found</h4>
                <div class="template-description"></div>
                <input type="hidden" name="v[<?php echo $templateKey[1]; ?>]" value="<?php echo CPJ_Tools::select_template( $templateKey[1] ); ?>" />
            </div>
        </div>
        <?php
        }
        
        public function templates_meta_modal( $post_ID )
        {
        ?>
        <!-- Modal -->
        <div class="modal modal-xlg modal-post fade" id="selectTemplateModal" tabindex="-1" role="dialog" aria-labelledby="selectTemplateLabel" aria-hidden="true">
        	<div class="modal-dialog">
        		<div class="modal-content">
        			<div class="modal-header">
        				<button type="button" class="close" data-dismiss="modal">
        					<span aria-hidden="true">
        						&times;
        					</span>
        					<span class="sr-only">
        						<?php _e( "Close", "post-page-manager" ); ?>
        					</span>
        				</button>
        				<h4 class="modal-title" id="selectTemplateLabel">
        					<?php _e( "Select Templates", "post-page-manager" ); ?>
        				</h4>
        			</div>
        			<div class="modal-body">
        				<div class="panel panel-fullwidth-15">
        					<ul id="templatesModalNavTabs" class="nav nav-tabs nav-tabs-justified">
        						<?php
                                $i = 0;
                                foreach( $this->templates as $templatesKey => $templatesValue )
                                {
                                    $i++;
                                    if( $i == 1 )
                                    {
                                        $st = 'class = "active in"';
                                    } else
                                    {
                                        $st = '';
                                    }
                                    $templateD = explode( '#', $templatesKey );
                                ?>
                                <li <?php echo $st; ?>>
                                	<a href="#<?php echo $templateD[1]; ?>-modal" data-toggle="tab">
                                        <?php echo $templateD[0]; ?>
                                    </a>
                                </li>
                                <?php
                                }
                                ?>
        					</ul>
        					<div id="templatesModalTabsContent" class="tab-content">
        						<?php
                                $i = 0;
                                foreach( $this->templates as $templatesKey => $templatesValue )
                                {
                                    $i++;
                                    if( $i == 1 )
                                    {
                                        $st = 'active in';
                                    } else
                                    {
                                        $st = '';
                                    }
                                    $templateD = explode( '#', $templatesKey );
                                ?>
        							<div class="tab-pane faden <?php echo $st; ?>" id="<?php echo $templateD[1]; ?>-modal">
        								<?php  $this->templates_meta_tabs_list( $templatesKey, $templatesValue ); ?>
        							</div>
        						<?php
                                }
                                ?>
        					</div>
        				</div>
        			</div>
        			<div class="modal-footer">
                        <input type="hidden" name="cpjACTION" value="metaboxTemsUpdate" />
                        <input type="hidden" name="key" value="<?php echo $post_ID; ?>" />
                        <?php wp_nonce_field( 'cpj-next-nonce', 'templatesManNextNonce' ); ?>
        				<button type="button" class="btn btn-default" data-dismiss="modal">
        					<?php _e( "Close", "post-page-manager" ); ?>
        				</button>
        				<button type="submit" class="btn btn-primary modalUpdateTemplates" disabled>
        					<?php _e( "Update Templates", "post-page-manager" ); ?>
        				</button>
        			</div>
        		</div>
        	</div>
        </div>
        <?php   
        }
    }
}